==> vcd-api-schemas-type-9.1.2.dev8.tar.gz: vcd-api-schemas-type-9.1.2.dev8/vcloud/api/rest/schema_v1_5/extension/__init__.py <==
"""
  Copyright (c) 2020 VMware, Inc. All rights reserved.
"""
from .resource_class_actions_type import ResourceClassActionsType
from .object_extensions_type import ObjectExtensionsType
from .selectors import Selectors
from .import_media_params_type import ImportMediaParamsType
from .stranded_item_vim_objects_type import StrandedItemVimObjectsType
from .amqp_settings_type import AmqpSettingsType
from .migrate_params_type import MigrateParamsType
from .amqp_settings_test_type import AmqpSettingsTestType
from .vmw_vm_host_affinity_rule_type import VMWVmHostAffinityRuleType
from .fence_pool_type import FencePoolType
from .vmw_vm_host_affinity_rules_type import VMWVmHostAffinityRulesType
from .component_manager_settings_type import ComponentManagerSettingsType
from .port_group_pool_type import PortGroupPoolType
from .serial_port_config_type import SerialPortConfigType
from .import_vm_as_v_app_params_type import ImportVmAsVAppParamsType
from .system_configuration_setting_type import SystemConfigurationSettingType
from .vxlan_pool_type import VxlanPoolType
from .api_filter_type import ApiFilterType
from .catalog_settings_type import CatalogSettingsType
from .acl_access_type import AclAccessType
from .lookup_service_params_type import LookupServiceParamsType
from .vmw_host_references_type import VMWHostReferencesType
from .admin_service_link_type import AdminServiceLinkType
from .vmw_vim_server_references_type import VMWVimServerReferencesType
from .vm_object_ref_type import VmObjectRefType
from .vmw_allocation_vapp_vdc_template_specification_type import VMWAllocationVappVdcTemplateSpecificationType
from .smtp_settings_type import SmtpSettingsType
from .licensing_virtual_machine_type import LicensingVirtualMachineType
from .vmw_vm_group_type import VMWVmGroupType
from .branding_settings_type import BrandingSettingsType
from .import_vm_into_existing_v_app_params_type import ImportVmIntoExistingVAppParamsType
from .vmw_reservation_pool_vdc_template_specification_type import VMWReservationPoolVdcTemplateSpecificationType
from .resource_pool_list_type import ResourcePoolListType
from .register_vim_server_params_type import RegisterVimServerParamsType
from .host_object_refs_type import HostObjectRefsType
from .ldap_user_attributes_type import LdapUserAttributesType
from .license_metrics_info_type import LicenseMetricsInfoType
from .api_filters_type import ApiFiltersType
from .vmw_vdc_template_binding_type import VMWVdcTemplateBindingType
from .system_configuration_setting_value_type import SystemConfigurationSettingValueType
from .update_provider_vdc_storage_profiles_params_type import UpdateProviderVdcStorageProfilesParamsType
from .numeric_range_type import NumericRangeType
from .nsx_t_manager_type import NsxTManagerType
from .system_configuration_settings_type import SystemConfigurationSettingsType
from .import_vm_as_v_app_template_params_type import ImportVmAsVAppTemplateParamsType
from .disk_datastore_type import DiskDatastoreType
from .operation_limits_settings_type import OperationLimitsSettingsType
from .vmw_provider_vdc_type import VMWProviderVdcType
from .lookup_service_settings_type import LookupServiceSettingsType
from .cpom_settings_type import CpomSettingsType
from .entity_rights_type import EntityRightsType
from .geneve_pool_type import GenevePoolType
from .host_object_ref_type import HostObjectRefType
from .datastores_type import DatastoresType
from .notifications_settings_type import NotificationsSettingsType
from .licensing_report_sample_type import LicensingReportSampleType
from .stranded_item_type import StrandedItemType
from .resource_pool_type import ResourcePoolType
from .managed_server_metrics import ManagedServerMetrics
from .vmw_provider_vdc_references_type import VMWProviderVdcReferencesType
from .vmw_discovered_resource_pools_type import VMWDiscoveredResourcePoolsType
from .vlan_pool_type import VlanPoolType
from .authorization_check_params_type import AuthorizationCheckParamsType
from .nsx_t_managers_type import NsxTManagersType
from .bundle_upload_socket_type import BundleUploadSocketType
from .organization_resource_pool_set_type import OrganizationResourcePoolSetType
from .virtual_machine_metrics import VirtualMachineMetrics
from .acl_rules_type import AclRulesType
from .vmw_vdc_template_specification_type import VMWVdcTemplateSpecificationType
from .kerberos_settings_type import KerberosSettingsType
from .vmw_network_pool_references_type import VMWNetworkPoolReferencesType
from .blocking_task_type import BlockingTaskType
from .host_type import HostType
from .vmw_vm_groups_type import VMWVmGroupsType
from .vim_object_ref_list_type import VimObjectRefListType
from .notification_type import NotificationType
from .licensing_managed_server_type import LicensingManagedServerType
from .stranded_item_vim_object_type import StrandedItemVimObjectType
from .vc_trust_store_update_params_type import VcTrustStoreUpdateParamsType
from .vmw_vdc_template_type import VMWVdcTemplateType
from .vim_object_refs_type import VimObjectRefsType
from .vmw_provider_vdc_params_type import VMWProviderVdcParamsType
from .update_rights_params_type import UpdateRightsParamsType
from .licensing_report_list_type import LicensingReportListType
from .server_type import ServerType
from .vds_context_type import VdsContextType
from .system_password_policy_settings_type import SystemPasswordPolicySettingsType
from .realm_type import RealmType
from .authorization_check_response_type import AuthorizationCheckResponseType
from .vim_server_type import VimServerType
from .vmw_allocation_pool_vdc_template_specification_type import VMWAllocationPoolVdcTemplateSpecificationType
from .vmw_host_groups_type import VMWHostGroupsType
from .extension_services_type import ExtensionServicesType
from .ldap_group_attributes_type import LdapGroupAttributesType
from .admin_file_descriptors_type import AdminFileDescriptorsType
from .admin_api_definitions_type import AdminApiDefinitionsType
from .vim_object_ref_type import VimObjectRefType
from .blocking_task_operation_params_type import BlockingTaskOperationParamsType
from .email_settings_type import EmailSettingsType
from .service_resource_type import ServiceResourceType
from .admin_api_definition_type import AdminApiDefinitionType
from .vm_object_refs_list_type import VmObjectRefsListType
from .v_sphere_web_client_url_type import VSphereWebClientUrlType
from .cbm_data_type import CbmDataType
from .vmw_vdc_template_list_type import VMWVdcTemplateListType
from .vmw_external_network_references_type import VMWExternalNetworkReferencesType
from .vmw_provider_vdc_resource_pool_set_type import VMWProviderVdcResourcePoolSetType
from .entity_references_type import EntityReferencesType
from .admin_service_type import AdminServiceType
from .vmw_named_vm_group_type import VMWNamedVmGroupType
from .ldap_settings_type import LdapSettingsType
from .vmw_discovered_resource_pool_type import VMWDiscoveredResourcePoolType
from .datastore_type import DatastoreType
from .user_entity_rights_type import UserEntityRightsType
from .vmw_host_group_type import VMWHostGroupType
from .vmw_vm_group_references_type import VMWVmGroupReferencesType
from .uber_admin_settings_type import UberAdminSettingsType
from .provider_vdc_merge_params_type import ProviderVdcMergeParamsType
from .tenant_migration_params_type import TenantMigrationParamsType
from .system_settings_type import SystemSettingsType
from .license_type import LicenseType
from .selector import Selector
from .vmw_storage_profile_type import VMWStorageProfileType
from .rights_type import RightsType
from .imported_disk_type import ImportedDiskType
from .admin_file_descriptor_type import AdminFileDescriptorType
from .right_refs_type import RightRefsType
from .licensing_report_type import LicensingReportType
from .vmw_storage_profiles_type import VMWStorageProfilesType
from .vmw_extension_type import VMWExtensionType
from .bundle_upload_params_type import BundleUploadParamsType
from .automatic_network_pool_reference_type import AutomaticNetworkPoolReferenceType
from .vm_vim_info_type import VmVimInfoType
from .general_settings_type import GeneralSettingsType
from .vmw_network_pool_type import VMWNetworkPoolType
from .import_vm_params_type import ImportVmParamsType
from .vmw_provider_vdc_resource_pool_type import VMWProviderVdcResourcePoolType
from .vc_trust_store_upload_socket_type import VcTrustStoreUploadSocketType
from .vmw_vdc_template_provider_vdc_specification_type import VMWVdcTemplateProviderVdcSpecificationType
from .blocking_task_update_progress_params_type import BlockingTaskUpdateProgressParamsType
from .update_resource_pool_set_params_type import UpdateResourcePoolSetParamsType
from .resource_class_type import ResourceClassType
from .acl_rule_type import AclRuleType
from .service_resources_type import ServiceResourcesType
from .admin_service_links_type import AdminServiceLinksType
from .object_extension_type import ObjectExtensionType
from .resource_class_action_type import ResourceClassActionType
from .resource_classes_type import ResourceClassesType
from .prepare_host_params_type import PrepareHostParamsType
from .versions_type import VersionsType
from .blocking_task_settings_type import BlockingTaskSettingsType
from .vmw_vdc_templates_type import VMWVdcTemplatesType
from .shield_manager_type import ShieldManagerType
from .vmw_external_network_type import VMWExternalNetworkType
from .vmw_provider_vdc_storage_profile_type import VMWProviderVdcStorageProfileType

==> vcd-api-schemas-type-10.3.0.dev72.tar.gz: vcd-api-schemas-type-10.3.0.dev72/vcloud/api/rest/schema_v1_5/extension/__init__.py <==
"""
  Copyright (c) 2021 VMware, Inc. All rights reserved.
"""
from .licensing_virtual_machine_type import LicensingVirtualMachineType
from .vmw_vdc_templates_type import VMWVdcTemplatesType
from .entity_references_type import EntityReferencesType
from .kerberos_settings_type import KerberosSettingsType
from .vmw_provider_vdc_references_type import VMWProviderVdcReferencesType
from .vmw_network_pool_type import VMWNetworkPoolType
from .general_settings_type import GeneralSettingsType
from .ldap_settings_type import LdapSettingsType
from .disk_datastore_type import DiskDatastoreType
from .api_filter_type import ApiFilterType
from .vmw_vdc_template_list_type import VMWVdcTemplateListType
from .vmw_storage_profile_type import VMWStorageProfileType
from .datastore_type import DatastoreType
from .vc_trust_store_update_params_type import VcTrustStoreUpdateParamsType
from .vmw_host_references_type import VMWHostReferencesType
from .nsx_t_manager_type import NsxTManagerType
from .bundle_upload_params_type import BundleUploadParamsType
from .vim_server_type import VimServerType
from .update_provider_vdc_storage_profiles_params_type import UpdateProviderVdcStorageProfilesParamsType
from .vmw_external_network_references_type import VMWExternalNetworkReferencesType
from .vmw_host_groups_type import VMWHostGroupsType
from .vmw_named_vm_group_type import VMWNamedVmGroupType
from .vc_trust_store_upload_socket_type import VcTrustStoreUploadSocketType
from .automatic_network_pool_reference_type import AutomaticNetworkPoolReferenceType
from .object_extensions_type import ObjectExtensionsType
from .tenant_migration_params_type import TenantMigrationParamsType
from .vim_object_ref_type import VimObjectRefType
from .vim_object_refs_type import VimObjectRefsType
from .vmw_extension_type import VMWExtensionType
from .api_filters_type import ApiFiltersType
from .vm_object_ref_type import VmObjectRefType
from .blocking_task_operation_params_type import BlockingTaskOperationParamsType
from .vmw_external_network_type import VMWExternalNetworkType
from .resource_class_actions_type import ResourceClassActionsType
from .stranded_item_type import StrandedItemType
from .imported_disk_type import ImportedDiskType
from .vmw_vdc_template_binding_type import VMWVdcTemplateBindingType
from .provider_vdc_merge_params_type import ProviderVdcMergeParamsType
from .resource_pool_type import ResourcePoolType
from .vmw_network_pool_references_type import VMWNetworkPoolReferencesType
from .lookup_service_settings_type import LookupServiceSettingsType
from .vm_object_refs_list_type import VmObjectRefsListType
from .admin_service_link_type import AdminServiceLinkType
from .admin_service_links_type import AdminServiceLinksType
from .virtual_machine_metrics import VirtualMachineMetrics
from .vmw_storage_profiles_type import VMWStorageProfilesType
from .managed_server_metrics import ManagedServerMetrics
from .server_type import ServerType
from .update_resource_pool_set_params_type import UpdateResourcePoolSetParamsType
from .vmw_discovered_resource_pools_type import VMWDiscoveredResourcePoolsType
from .vmw_flex_vdc_template_specification_type import VMWFlexVdcTemplateSpecificationType
from .vmw_provider_vdc_storage_profile_type import VMWProviderVdcStorageProfileType
from .stranded_item_vim_objects_type import StrandedItemVimObjectsType
from .import_vm_into_existing_v_app_params_type import ImportVmIntoExistingVAppParamsType
from .vlan_pool_type import VlanPoolType
from .admin_service_type import AdminServiceType
from .vmw_allocation_pool_vdc_template_specification_type import VMWAllocationPoolVdcTemplateSpecificationType
from .vdc_template_network_profile_type import VdcTemplateNetworkProfileType
from .vmw_provider_vdc_resource_pool_set_type import VMWProviderVdcResourcePoolSetType
from .system_settings_type import SystemSettingsType
from .vmw_provider_vdc_resource_pool_type import VMWProviderVdcResourcePoolType
from .uber_admin_settings_type import UberAdminSettingsType
from .service_resource_type import ServiceResourceType
from .licensing_report_list_type import LicensingReportListType
from .vdc_template_network_backing_type import VdcTemplateNetworkBackingType
from .cbm_data_type import CbmDataType
from .stranded_item_vim_object_type import StrandedItemVimObjectType
from .vmw_host_group_type import VMWHostGroupType
from .lookup_service_params_type import LookupServiceParamsType
from .prepare_host_params_type import PrepareHostParamsType
from .user_entity_rights_type import UserEntityRightsType
from .amqp_settings_type import AmqpSettingsType
from .operation_limits_settings_type import OperationLimitsSettingsType
from .license_type import LicenseType
from .acl_rules_type import AclRulesType
from .vmw_vim_server_references_type import VMWVimServerReferencesType
from .import_vm_as_v_app_params_type import ImportVmAsVAppParamsType
from .admin_file_descriptors_type import AdminFileDescriptorsType
from .resource_classes_type import ResourceClassesType
from .notifications_settings_type import NotificationsSettingsType
from .register_vim_server_params_type import RegisterVimServerParamsType
from .bundle_upload_socket_type import BundleUploadSocketType
from .vxlan_pool_type import VxlanPoolType
from .shield_manager_type import ShieldManagerType
from .selector import Selector
from .catalog_settings_type import CatalogSettingsType
from .selectors import Selectors
from .vmw_vm_host_affinity_rules_type import VMWVmHostAffinityRulesType
from .import_media_params_type import ImportMediaParamsType
from .fence_pool_type import FencePoolType
from .geneve_pool_type import GenevePoolType
from .v_sphere_web_client_url_type import VSphereWebClientUrlType
from .licensing_managed_server_type import LicensingManagedServerType
from .vmw_vm_groups_type import VMWVmGroupsType
from .smtp_settings_type import SmtpSettingsType
from .authorization_check_response_type import AuthorizationCheckResponseType
from .resource_class_type import ResourceClassType
from .vim_object_ref_list_type import VimObjectRefListType
from .right_refs_type import RightRefsType
from .licensing_report_type import LicensingReportType
from .object_extension_type import ObjectExtensionType
from .vmw_allocation_vapp_vdc_template_specification_type import VMWAllocationVappVdcTemplateSpecificationType
from .vmw_vm_host_affinity_rule_type import VMWVmHostAffinityRuleType
from .resource_class_action_type import ResourceClassActionType
from .host_object_ref_type import HostObjectRefType
from .blocking_task_update_progress_params_type import BlockingTaskUpdateProgressParamsType
from .extension_services_type import ExtensionServicesType
from .vmw_vdc_template_provider_vdc_specification_type import VMWVdcTemplateProviderVdcSpecificationType
from .admin_api_definition_type import AdminApiDefinitionType
from .blocking_task_type import BlockingTaskType
from .license_metrics_info_type import LicenseMetricsInfoType
from .authorization_check_params_type import AuthorizationCheckParamsType
from .admin_api_definitions_type import AdminApiDefinitionsType
from .branding_settings_type import BrandingSettingsType
from .cpom_settings_type import CpomSettingsType
from .resource_pool_list_type import ResourcePoolListType
from .email_settings_type import EmailSettingsType
from .service_resources_type import ServiceResourcesType
from .versions_type import VersionsType
from .vmw_vdc_template_type import VMWVdcTemplateType
from .amqp_settings_test_type import AmqpSettingsTestType
from .datastores_type import DatastoresType
from .port_group_pool_type import PortGroupPoolType
from .vmw_provider_vdc_params_type import VMWProviderVdcParamsType
from .acl_rule_type import AclRuleType
from .import_vm_params_type import ImportVmParamsType
from .admin_file_descriptor_type import AdminFileDescriptorType
from .import_vm_as_v_app_template_params_type import ImportVmAsVAppTemplateParamsType
from .vmw_provider_vdc_type import VMWProviderVdcType
from .blocking_task_settings_type import BlockingTaskSettingsType
from .vmw_reservation_pool_vdc_template_specification_type import VMWReservationPoolVdcTemplateSpecificationType
from .vmw_vm_group_references_type import VMWVmGroupReferencesType
from .numeric_range_type import NumericRangeType
from .host_object_refs_type import HostObjectRefsType
from .vds_context_type import VdsContextType
from .vm_vim_info_type import VmVimInfoType
from .realm_type import RealmType
from .acl_access_type import AclAccessType
from .system_password_policy_settings_type import SystemPasswordPolicySettingsType
from .entity_rights_type import EntityRightsType
from .notification_type import NotificationType
from .licensing_report_sample_type import LicensingReportSampleType
from .vmw_vm_group_type import VMWVmGroupType
from .serial_port_config_type import SerialPortConfigType
from .host_type import HostType
from .migrate_params_type import MigrateParamsType
from .rights_type import RightsType
from .organization_resource_pool_set_type import OrganizationResourcePoolSetType
from .component_manager_settings_type import ComponentManagerSettingsType
from .update_rights_params_type import UpdateRightsParamsType
from .vmw_vdc_template_specification_type import VMWVdcTemplateSpecificationType
from .ldap_group_attributes_type import LdapGroupAttributesType
from .ldap_user_attributes_type import LdapUserAttributesType
from .vmw_discovered_resource_pool_type import VMWDiscoveredResourcePoolType
from .nsx_t_managers_type import NsxTManagersType
